@@ -785,6 +785,21 @@ typedef struct SDL2_MouseMotionEvent
     Sint32 yrel;
 } SDL2_MouseMotionEvent;
 
+typedef struct SDL2PRERELEASE_MouseMotionEvent
+{
+    Uint32 type;
+    Uint32 timestamp;
+    Uint32 windowID;
+    Uint8 state;
+    Uint8 padding1;
+    Uint8 padding2;
+    Uint8 padding3;
+    int x;
+    int y;
+    int xrel;
+    int yrel;
+} SDL2PRERELEASE_MouseMotionEvent;
+
 typedef struct SDL2_MouseButtonEvent
 {
     Uint32 type;
@@ -799,6 +814,19 @@ typedef struct SDL2_MouseButtonEvent
     Sint32 y;
 } SDL2_MouseButtonEvent;
 
+typedef struct SDL2PRERELEASE_MouseButtonEvent
+{
+    Uint32 type;
+    Uint32 timestamp;
+    Uint32 windowID;
+    Uint8 button;
+    Uint8 state;
+    Uint8 padding1;
+    Uint8 padding2;
+    int x;
+    int y;
+} SDL2PRERELEASE_MouseButtonEvent;
+
 typedef struct SDL2_MouseWheelEvent
 {
     Uint32 type;
@@ -814,6 +842,15 @@ typedef struct SDL2_MouseWheelEvent
     Sint32 mouseY;
 } SDL2_MouseWheelEvent;
 
+typedef struct SDL2PRERELEASE_MouseWheelEvent
+{
+    Uint32 type;
+    Uint32 timestamp;
+    Uint32 windowID;
+    int x;
+    int y;
+} SDL2PRERELEASE_MouseWheelEvent;
+
 typedef struct SDL2_JoyAxisEvent
 {
     Uint32 type;
@@ -1164,6 +1201,8 @@ typedef struct SDL2_AudioStream
     SDL2_AudioFormat dst_format;
 
     /* these are used when this stream is powering an opened audio device, and not when just used as an SDL2 audio stream. */
+    int bytes_per_callbacks;
+    void *callback2_buffer;
     SDL2_AudioCallback callback2;
     void *callback2_userdata;
     SDL_AudioStream *dataqueue3;
@@ -1413,6 +1452,41 @@ typedef struct SDL2_Surface
     int refcount;               /**< Read-mostly */
 } SDL2_Surface;
 
+/* SDL3 has different SDL_GLattr enum since 19 (SDL_GL_CONTEXT_EGL in SDL2 vs SDL_GL_CONTEXT_FLAGS in SDL3),
+ * SDL2 apps like GoldSrc will be unhappy with SDL_GL_CONTEXT_PROFILE_MASK or sth.
+ */
+typedef enum SDL2_GLattr
+{
+    SDL2_GL_RED_SIZE,                    /**< the minimum number of bits for the red channel of the color buffer; defaults to 3. */
+    SDL2_GL_GREEN_SIZE,                  /**< the minimum number of bits for the green channel of the color buffer; defaults to 3. */
+    SDL2_GL_BLUE_SIZE,                   /**< the minimum number of bits for the blue channel of the color buffer; defaults to 2. */
+    SDL2_GL_ALPHA_SIZE,                  /**< the minimum number of bits for the alpha channel of the color buffer; defaults to 0. */
+    SDL2_GL_BUFFER_SIZE,                 /**< the minimum number of bits for frame buffer size; defaults to 0. */
+    SDL2_GL_DOUBLEBUFFER,                /**< whether the output is single or double buffered; defaults to double buffering on. */
+    SDL2_GL_DEPTH_SIZE,                  /**< the minimum number of bits in the depth buffer; defaults to 16. */
+    SDL2_GL_STENCIL_SIZE,                /**< the minimum number of bits in the stencil buffer; defaults to 0. */
+    SDL2_GL_ACCUM_RED_SIZE,              /**< the minimum number of bits for the red channel of the accumulation buffer; defaults to 0. */
+    SDL2_GL_ACCUM_GREEN_SIZE,            /**< the minimum number of bits for the green channel of the accumulation buffer; defaults to 0. */
+    SDL2_GL_ACCUM_BLUE_SIZE,             /**< the minimum number of bits for the blue channel of the accumulation buffer; defaults to 0. */
+    SDL2_GL_ACCUM_ALPHA_SIZE,            /**< the minimum number of bits for the alpha channel of the accumulation buffer; defaults to 0. */
+    SDL2_GL_STEREO,                      /**< whether the output is stereo 3D; defaults to off. */
+    SDL2_GL_MULTISAMPLEBUFFERS,          /**< the number of buffers used for multisample anti-aliasing; defaults to 0. */
+    SDL2_GL_MULTISAMPLESAMPLES,          /**< the number of samples used around the current pixel used for multisample anti-aliasing. */
+    SDL2_GL_ACCELERATED_VISUAL,          /**< set to 1 to require hardware acceleration, set to 0 to force software rendering; defaults to allow either. */
+    SDL2_GL_RETAINED_BACKING,            /**< not used (deprecated). */
+    SDL2_GL_CONTEXT_MAJOR_VERSION,       /**< OpenGL context major version. */
+    SDL2_GL_CONTEXT_MINOR_VERSION,       /**< OpenGL context minor version. */
+    SDL2_GL_CONTEXT_EGL,                 /**< deprecated: set SDL_GL_CONTEXT_PROFILE_MASK to SDL_GL_CONTEXT_PROFILE_ES to enable instead. */
+    SDL2_GL_CONTEXT_FLAGS,               /**< some combination of 0 or more of elements of the SDL_GLcontextFlag enumeration; defaults to 0. */
+    SDL2_GL_CONTEXT_PROFILE_MASK,        /**< type of GL context (Core, Compatibility, ES). See SDL_GLprofile; default value depends on platform. */
+    SDL2_GL_SHARE_WITH_CURRENT_CONTEXT,  /**< OpenGL context sharing; defaults to 0. */
+    SDL2_GL_FRAMEBUFFER_SRGB_CAPABLE,    /**< requests sRGB capable visual; defaults to 0. (>= SDL 2.0.1) */
+    SDL2_GL_CONTEXT_RELEASE_BEHAVIOR,    /**< sets context the release behavior; defaults to 1. (>= SDL 2.0.4) */
+    SDL2_GL_CONTEXT_RESET_NOTIFICATION,
+    SDL2_GL_CONTEXT_NO_ERROR,
+    SDL2_GL_FLOATBUFFERS
+} SDL2_GLattr;
+
 #define SDL_VIRTUAL_JOYSTICK_DESC_VERSION 1
 
 typedef struct SDL2_VirtualJoystickDesc
