@@ -576,8 +576,8 @@ SDL2_PROTO(int,GL_LoadLibrary,(const char *a))
 SDL2_PROTO(void*,GL_GetProcAddress,(const char *a))
 SDL2_PROTO(void,GL_UnloadLibrary,(void))
 SDL2_PROTO(SDL2_bool,GL_ExtensionSupported,(const char *a))
-SDL2_PROTO(int,GL_SetAttribute,(SDL_GLAttr a, int b))
-SDL2_PROTO(int,GL_GetAttribute,(SDL_GLAttr a, int *b))
+SDL2_PROTO(int,GL_SetAttribute,(SDL2_GLattr a, int b))
+SDL2_PROTO(int,GL_GetAttribute,(SDL2_GLattr a, int *b))
 SDL2_PROTO(SDL_GLContext,GL_CreateContext,(SDL_Window *a))
 SDL2_PROTO(int,GL_MakeCurrent,(SDL_Window *a, SDL_GLContext b))
 SDL2_PROTO(SDL_Window*,GL_GetCurrentWindow,(void))
