@@ -187,7 +187,7 @@ SDL3_SYM_RENAMED(void,FreeCursor,DestroyCursor,(SDL_Cursor *a),(a),)
 SDL3_SYM_PASSTHROUGH(SDL_GLContext,GL_CreateContext,(SDL_Window *a),(a),return)
 SDL3_SYM(bool,GL_DestroyContext,(SDL_GLContext a),(a),return)
 SDL3_SYM_PASSTHROUGH_BOOL(bool,GL_ExtensionSupported,(const char *a),(a),return)
-SDL3_SYM_PASSTHROUGH_RETCODE(bool,GL_GetAttribute,(SDL_GLAttr a, int *b),(a,b),return)
+SDL3_SYM(bool,GL_GetAttribute,(SDL_GLAttr a, int *b),(a,b),return)
 SDL3_SYM_PASSTHROUGH(SDL_GLContext,GL_GetCurrentContext,(void),(),return)
 SDL3_SYM_PASSTHROUGH(SDL_Window*,GL_GetCurrentWindow,(void),(),return)
 SDL3_SYM_PASSTHROUGH(void*,GL_GetProcAddress,(const char *a),(a),return)
@@ -195,7 +195,7 @@ SDL3_SYM(bool,GL_GetSwapInterval,(int *a),(a),return)
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,GL_LoadLibrary,(const char *a),(a),return)
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,GL_MakeCurrent,(SDL_Window *a, SDL_GLContext b),(a,b),return)
 SDL3_SYM_PASSTHROUGH(void,GL_ResetAttributes,(void),(),)
-SDL3_SYM_PASSTHROUGH_RETCODE(bool,GL_SetAttribute,(SDL_GLAttr a, int b),(a,b),return)
+SDL3_SYM(bool,GL_SetAttribute,(SDL_GLAttr a, int b),(a,b),return)
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,GL_SetSwapInterval,(int a),(a),return)
 SDL3_SYM(bool,GL_SwapWindow,(SDL_Window *a),(a),return)
 SDL3_SYM_PASSTHROUGH(void,GL_UnloadLibrary,(void),(),)
